<?php

namespace Erp\Master\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Erp\Master\Actions\StudentAction;
use Erp\Master\Http\Requests\StudentActionRequest;
use Erp\Master\Http\Resources\StudentResource;
use Erp\Master\Models\Student;

/**
 * Admin web controller class.
 */
class StudentActionController extends BaseController
{

    /**
     * Action controller function for student.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(StudentActionRequest $request, Student $student, $action)
    {
        try {
            $request = $request->all();
            $student = StudentAction::run($action, $student, $request);

            $data = new StudentResource($student);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('master::student.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('master/student/' . $student->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('master/student/' . $student->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
