<?php

namespace Erp\Master\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Erp\Master\Models\Student;

class StudentPolicy
{

    use StudentAction;
    use StudentReport;
    use StudentWorkflow;

    /**
     * Determine if the given user can view the student.
     *
     * @param Authenticatable $user
     * @param Student $student
     *
     * @return bool
     */
    public function view(Authenticatable $user, Student $student)
    {
        if ($authUser->canDo('master.student.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $student->is_owner;
    }

    /**
     * Determine if the given user can create a student.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('master.student.create');
    }

    /**
     * Determine if the given user can update the given student.
     *
     * @param Authenticatable $user
     * @param Student $student
     *
     * @return bool
     */
    public function update(Authenticatable $user, Student $student)
    {
        if ($user->canDo('master.student.edit') && $user->isAdmin()) {
            return true;
        }

        return $student->is_owner;
    }

    /**
     * Determine if the given user can delete the given student.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Student $student)
    {
        return $student->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
